import { Button, Form, Input, Select, Skeleton, Pagination } from "antd";
import { useAssessmentStandardContext } from "./assessment-standard-provider";
import { api, useSport } from "@nice/client";
import toast from "react-hot-toast";
import { useState } from 'react';
const { Search } = Input;
export default function SportCreateContent() {
    const { form, sportProjectList, sportProjectLoading } = useAssessmentStandardContext();
    const { createSportProject, softDeleteByIds } = useSport();
    const { data: fatherTrainContent } = api.trainContent.findFirst.useQuery({
        where: {
            type: "SPORTS",
            title: "体能考核"
        }
    })
    const [searchValue, setSearchValue] = useState('');
    const [currentPage, setCurrentPage] = useState(1);
    const [pageSize, setPageSize] = useState(10);
    const handleCreateProject = async () => {
        if (form.getFieldsValue().createProjectName && form.getFieldsValue().unit) {
            await createSportProject.mutateAsync({
                data: {
                    name: form.getFieldsValue().createProjectName,
                    type: "sport",
                    unit: form.getFieldsValue().unit,
                    isAscending: true,
                    trainContent: {
                        create: {
                            title: form.getFieldsValue().createProjectName,
                            type: "SPORT",
                            parentId: fatherTrainContent?.id
                        }
                    }
                }
            } as any)
            toast.success("创建项目成功")
            form.resetFields()
        } else {
            toast.error("请输入项目名称或成绩单位")
        }
    }
    const handleDeleteProject = async (id: string) => {
        // console.log(id)
        await softDeleteByIds.mutateAsync({
            ids: [id]
        } as any)
        toast.success("删除项目成功")
    }
    const handleSearch = (value) => {
        setSearchValue(value);
        setCurrentPage(1);
    };
    return (
        <>
            <Form form={form} layout="vertical">
                <div className="flex items-center space-x-4  w-1/3">
                    <Form.Item label="创建项目" name="createProjectName">
                        <Input placeholder="请输入创建的项目名称" className="mr-2" />
                    </Form.Item>
                    <Form.Item label="成绩单位" name="unit" className='w-32'>
                        <Select
                            className='mr-2 w-24'
                            placeholder="请选择成绩单位"
                            options={[
                                { value: 'time', label: '时间' },
                                { value: 'count', label: '次数' },
                            ]}
                        ></Select>
                    </Form.Item>
                    <Button type="primary" className='mt-10 ml-2' onClick={handleCreateProject}>创建项目</Button>
                </div>
                {sportProjectLoading ?
                    <Skeleton></Skeleton> :
                    <div className='flex  my-3 max-h-48 overflow-y-auto'>
                        {sportProjectList?.filter(item=>item.deletedAt === null)?.map((item) => (
                            <div 
                                key={item.id} 
                                className='w-full flex justify-between items-center p-4 my-3 bg-white rounded-lg shadow-sm border border-gray-100 hover:shadow-md transition-shadow duration-200'
                            >
                                <div className='flex items-center'>
                                    <span className='h-4 w-1 bg-blue-500 rounded-full mr-3'></span>
                                    <div className='font-medium text-gray-800'>
                                        {item.name}
                                        <span className='text-gray-500 text-sm ml-2'>（{item.unit}）</span>
                                    </div>
                                </div>
                                <button 
                                    className='text-gray-400 hover:text-red-500 transition-colors duration-200 flex items-center gap-1 px-2 py-1 rounded-md hover:bg-red-50'
                                    onClick={() => handleDeleteProject(item.id)}
                                >
                                    <svg xmlns="http://www.w3.org/2000/svg" className="h-4 w-4" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M19 7l-.867 12.142A2 2 0 0116.138 21H7.862a2 2 0 01-1.995-1.858L5 7m5 4v6m4-6v6m1-10V4a1 1 0 00-1-1h-4a1 1 0 00-1 1v3M4 7h16" />
                                    </svg>
                                    <span>删除</span>
                                </button>
                            </div>
                        ))}
                    </div>
                }
            </Form>
            {/* <Search
                placeholder="搜索..."
                allowClear
                value={searchValue}
                onChange={(e) => {
                    if (!e.target.value) {
                        setSearchValue('');
                        setCurrentPage(1);
                    } else {
                        setSearchValue(e.target.value);
                    }
                }}
                onSearch={handleSearch}
                style={{ width: 200 }}
            /> */}
        </>
    )
}