import React, { useState } from 'react';
import { Card, Row, Col, Divider } from 'antd';
import ReactEcharts from 'echarts-for-react';

const Dashboard = () => {
  // 在这里获取你的项目数据
  const [data, setData] = useState({
    projectInfo: {
      name: '训练管理系统',
      type: '软件开发',
      status: '进行中',
      department: '技术研发中心',
      client: '软件小组',
      supervisor: '项目监理公司',
      contractor: '开发团队',
      planStartDate: '2023-10-01',
      planEndDate: '2024-03-31',
      actualStartDate: '2023-10-05',
      actualEndDate: '待定'
    },
    attendance: {
      personnel: { present: 15, absent: 5, leave: 2 }
    },
    training: {
      // 参训内容数据
      contents: [
        { value: 8, name: '岗位训练' },
        { value: 6, name: '共同科目' },
        { value: 4, name: '通用四项' },
        { value: 2, name: '其他' }
      ],
      // 参训时长数据
      hours: [
        { value: 25, name: '已完成' },
        { value: 10, name: '进行中' },
        { value: 5, name: '未开始' }
      ]
    },
    materials: {
      planned: [10, 15, 20],
      actual: [5, 8, 12]
    }
  });

  // 人员出勤率图表配置 - 优化样式
  const personnelAttendanceOption = {
    tooltip: {
      trigger: 'item',
      backgroundColor: 'rgba(0,21,41,0.8)',
      borderColor: 'rgba(32,120,160,0.8)',
      textStyle: { color: '#fff' },
      formatter: '{a} <br/>{b}: {c}人 ({d}%)'
    },
    legend: {
      orient: 'vertical',
      right: 10,
      top: 'center',
      icon: 'circle',
      itemWidth: 8,
      itemHeight: 8,
      textStyle: { color: '#fff', fontSize: 14 }
    },
    series: [{
      name: '人员出勤率',
      type: 'pie',
      radius: ['50%', '70%'],
      center: ['35%', '50%'],
      avoidLabelOverlap: true,
      itemStyle: {
        borderRadius: 0,
        borderWidth: 1,
        borderColor: 'rgba(32,120,160,0.8)',
      },
      label: {
        show: true,
        position: 'inside',
        formatter: '{d}%',
        fontSize: 10,
        color: '#fff',
      },
      labelLine: {
        show: false
      },
      emphasis: {
        label: {
          show: true,
          fontSize: 12,
          fontWeight: 'bold'
        }
      },
      data: [
        {
          value: data.attendance.personnel.present,
          name: '在位',
          itemStyle: { color: '#3DD598' }
        },
        {
          value: data.attendance.personnel.absent,
          name: '不在位',
          itemStyle: { color: '#FFB076' }
        },
        {
          value: data.attendance.personnel.leave,
          name: '请假',
          itemStyle: { color: '#FC5A5A' }
        }
      ]
    }]
  };
  // 参训内容饼图配置
  const trainingContentsOption = {
    tooltip: {
      trigger: 'item',
      backgroundColor: 'rgba(0,21,41,0.8)',
      borderColor: 'rgba(32,120,160,0.8)',
      textStyle: { color: '#fff' },
      formatter: '{a} <br/>{b}: {c}项 ({d}%)'
    },
    legend: {
      orient: 'vertical',
      right: 10,
      top: 'center',
      itemWidth: 8,
      itemHeight: 8,
      icon: 'circle',
      textStyle: { color: '#fff', fontSize: 14 }
    },
    series: [{
      name: '参训内容',
      type: 'pie',
      radius: ['50%', '70%'],
      center: ['35%', '50%'],
      avoidLabelOverlap: true,
      itemStyle: {
        borderRadius: 0,
        borderWidth: 1,
        borderColor: 'rgba(32,120,160,0.8)',
      },
      label: {
        show: true,
        position: 'inside',
        formatter: '{d}%',
        fontSize: 10,
        color: '#fff'
      },
      labelLine: {
        show: false
      },
      emphasis: {
        label: {
          show: true,
          fontSize: 12,
          fontWeight: 'bold'
        }
      },
      data: [
        {
          value: data.training.contents[0].value,
          name: data.training.contents[0].name,
          itemStyle: { color: '#4FDFFF' }
        },
        {
          value: data.training.contents[1].value,
          name: data.training.contents[1].name,
          itemStyle: { color: '#FFCA28' }
        },
        {
          value: data.training.contents[2].value,
          name: data.training.contents[2].name,
          itemStyle: { color: '#3DD598' }
        },
        {
          value: data.training.contents[3].value,
          name: data.training.contents[3].name,
          itemStyle: { color: '#FC5A5A' }
        }
      ]
    }]
  };
  // 参训时长饼图配置
  const trainingHoursOption = {
    tooltip: {
      trigger: 'item',
      backgroundColor: 'rgba(0,21,41,0.8)',
      borderColor: 'rgba(32,120,160,0.8)',
      textStyle: { color: '#fff' },
      formatter: '{a} <br/>{b}: {c}小时 ({d}%)'
    },
    legend: {
      orient: 'vertical',
      right: 10,
      top: 'center',
      itemWidth: 8,
      itemHeight: 8,
      icon: 'circle',
      textStyle: { color: '#fff', fontSize: 14 }
    },
    series: [{
      name: '参训时长',
      type: 'pie',
      radius: ['50%', '70%'],
      center: ['35%', '50%'],
      avoidLabelOverlap: true,
      itemStyle: {
        borderRadius: 0,
        borderWidth: 1,
        borderColor: 'rgba(32,120,160,0.8)',
      },
      label: {
        show: true,
        position: 'inside',
        formatter: '{d}%',
        fontSize: 10,
        color: '#fff'
      },
      labelLine: {
        show: false
      },
      emphasis: {
        label: {
          show: true,
          fontSize: 12,
          fontWeight: 'bold'
        }
      },
      data: [
        {
          value: data.training.hours[0].value,
          name: data.training.hours[0].name,
          itemStyle: { color: '#4FDFFF' }
        },
        {
          value: data.training.hours[1].value,
          name: data.training.hours[1].name,
          itemStyle: { color: '#FFB076' }
        },
        {
          value: data.training.hours[2].value,
          name: data.training.hours[2].name,
          itemStyle: { color: '#FC5A5A' }
        }
      ]
    }]
  };
  // 任务完成情况柱状图配置
  const materialsOption = {
    tooltip: {
      trigger: 'axis',
      backgroundColor: 'rgba(0,21,41,0.8)',
      borderColor: 'rgba(32,120,160,0.8)',
      textStyle: { color: '#fff' },
      axisPointer: {
        type: 'shadow'
      }
    },
    legend: {
      data: ['上半年', '下半年'],
      right: 10,
      top: 10,
      textStyle: {
        color: '#fff',
        fontSize: 10
      }
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      top: '22%',
      containLabel: true
    },
    xAxis: {
      type: 'category',
      data: ['任务A', '任务B', '任务C'],
      axisLine: {
        lineStyle: {
          color: 'rgba(255,255,255,0.3)'
        }
      },
      axisLabel: {
        color: '#fff',
        fontSize: 10
      }
    },
    yAxis: {
      type: 'value',
      axisLine: {
        show: true,
        lineStyle: {
          color: 'rgba(255,255,255,0.3)'
        }
      },
      splitLine: {
        lineStyle: {
          color: 'rgba(255,255,255,0.1)',
          type: 'dashed'
        }
      },
      axisLabel: {
        color: '#fff',
        fontSize: 10
      }
    },
    series: [
      {
        name: '上半年',
        type: 'bar',
        barWidth: '25%',
        itemStyle: {
          color: '#4FDFFF'
        },
        emphasis: {
          itemStyle: {
            color: '#6ab0f0'
          }
        },
        data: data.materials.planned
      },
      {
        name: '下半年',
        type: 'bar',
        barWidth: '25%',
        itemStyle: {
          color: '#FFCA28'
        },
        emphasis: {
          itemStyle: {
            color: '#FFB75C'
          }
        },
        data: data.materials.actual
      }
    ]
  };
  // 项目进度甘特图配置
  const ganttChartOption = {
    backgroundColor: 'transparent',
    tooltip: {
      trigger: 'item',
      formatter: function (params) {
        if (params.seriesName === '实际完成' || params.seriesName === '计划完成') {
          return `${params.name}<br/>${params.seriesName}: ${params.value[0]} ~ ${params.value[1]}`;
        }
        return params.name;
      },
      backgroundColor: 'rgba(0,21,41,0.8)',
      borderColor: 'rgba(32,120,160,0.8)',
      textStyle: { color: '#fff'}
    },
    legend: {
      data: ['计划完成', '实际完成', '超时完成'],
      top: 0,
      right: 10,
      textStyle: { color: '#fff', fontSize: 12 },
      itemWidth: 15,
      itemHeight: 10
    },
    grid: {
      top: 30,
      bottom: 30,
      left: 100,
      right: 20
    },
    xAxis: {
      type: 'time',
      axisLine: { lineStyle: { color: 'rgba(255,255,255,0.3)' } },
      axisLabel: {
        color: '#fff',
        fontSize: 10,
        formatter: '{yyyy}.{MM}.{dd}',
        rotate: 45,
        margin: 8,
        align: 'center',
        interval: 'auto',
        hideOverlap: true
      },
      splitLine: {
        show: true,
        lineStyle: { color: 'rgba(255,255,255,0.1)', type: 'dashed' }
      },
      min: '2019-02-01',
      max: '2019-04-30'
    },
    yAxis: {
      type: 'category',
      data: ['岗位训练', '共同科目', '通用四项'],
      axisLine: { lineStyle: { color: 'rgba(255,255,255,0.3)' } },
      axisLabel: {
        color: '#fff',
        fontSize: 12,
        margin: 20
      },
      inverse: true
    },
    series: [
      {
        name: '计划完成',
        type: 'bar',
        stack: 'same',
        itemStyle: { color: '#FFCA28' },
        barWidth: 20,
        data: [
          {
            name: '岗位训练',
            value: ['2019-03-08', '2019-04-17']
          },
          {
            name: '共同科目',
            value: ['2019-02-20', '2019-03-07']
          },
          {
            name: '通用四项',
            value: ['2019-02-05', '2019-02-26']
          }
        ]
      },
      {
        name: '实际完成',
        type: 'bar',
        stack: 'same',
        itemStyle: { color: '#4FDFFF' },
        barWidth: 20,
        data: [
          {
          },
          {
            name: '共同科目',
            value: ['2019-02-20', '2019-03-05']
          },
          {}
        ]
      },
      {
        name: '超时完成',
        type: 'bar',
        stack: 'same',
        itemStyle: { color: '#FC5A5A' },
        barWidth: 20,
        data: [
          // 空数据
          {},
          {},
          {
            name: '通用四项',
            value: ['2019-02-26', '2019-02-27']
          }
        ]
      },
      // 添加当前日期标记
      {
        name: '当前日期',
        type: 'line',
        markLine: {
          symbol: ['none', 'none'],
          label: {
            show: false
          },
          lineStyle: {
            color: '#fff',
            type: 'dashed',
            width: 1
          },
          data: [
            {
              xAxis: '2019-02-27'
            }
          ]
        }
      }
    ]
  };

  // 六边形背景SVG
  const hexagonBg = `
    <svg width="100%" height="100%" xmlns="http://www.w3.org/2000/svg">
      <defs>
        <pattern id="hexagons" width="50" height="43.4" patternUnits="userSpaceOnUse" patternTransform="scale(5)">
          <path d="M 0,25 12.5,0 37.5,0 50,25 37.5,50 12.5,50 Z" 
                stroke="rgba(32,120,160,0.2)" stroke-width="0.5" fill="none"/>
        </pattern>
      </defs>
      <rect width="100%" height="100%" fill="url(#hexagons)" />
    </svg>
  `;

  // 卡片通用样式
  const cardStyle = {
    backgroundColor: 'rgba(0,21,41,0.7)',
    color: 'white',
    border: '1px solid rgba(32,120,160,0.8)',
    boxShadow: '0 0 15px rgba(0,100,200,0.3)'
  };

  const headerStyle = {
    color: '#4FDFFF',
    borderBottom: '1px solid rgba(32,120,160,0.8)',
    fontSize: '16px',
    fontWeight: 'bold'
  };

  return (
    <div style={{
      padding: '20px',
      minHeight: '100vh',
      background: 'linear-gradient(135deg, #001529 0%, #003366 100%)',
      position: 'relative',
      overflow: 'hidden'
    }}>
      {/* 六边形背景 */}
      <div dangerouslySetInnerHTML={{ __html: hexagonBg }} style={{
        position: 'absolute',
        top: 0,
        left: 0,
        width: '100%',
        height: '100%',
        zIndex: 0
      }} />

      <div style={{ position: 'relative', zIndex: 1 }}>
        <h1 style={{
          textAlign: 'center',
          color: '#4FDFFF',
          marginBottom: '20px',
          textShadow: '0 0 10px rgba(79,223,255,0.5)'
        }}>训练管理系统数据看板</h1>

        <div style={{
          position: 'absolute',
          top: '20px',
          left: '20px',
          fontSize: '14px',
          color: '#fff'
        }}>
          {new Date().toLocaleString()} 星期{['日', '一', '二', '三', '四', '五', '六'][new Date().getDay()]}
        </div>

        <Row gutter={[16, 16]}>
          <Col span={8}>
            <Card
              title="项目概况"
              bordered={false}
              style={{...cardStyle,height:'100%'}}
              headStyle={headerStyle}
            >
              <div style={{ display: 'flex', flexDirection: 'column', gap: '8px' }}>
              {/* <div style={{ display: 'flex' }}>
                  <span style={{ width: '100px' }}></span>
                </div>
                <div style={{ display: 'flex' }}>
                  <span style={{ width: '100px' }}></span>
                </div>
                <div style={{ display: 'flex' }}>
                  <span style={{ width: '100px' }}></span>
                </div> */}
                <div style={{ display: 'flex' }}>
                  <span style={{ width: '100px' }}>工程名称: </span>
                  <span>{data.projectInfo.name}</span>
                </div>
                <div style={{ display: 'flex' }}>
                  <span style={{ width: '100px' }}>开发单位: </span>
                  <span>{data.projectInfo.client}</span>
                </div>
                <div style={{ display: 'flex' }}>
                  <span style={{ width: '100px' }}>计划开始:</span>
                  <span>{data.projectInfo.planStartDate}</span>
                </div>
                <div style={{ display: 'flex' }}>
                  <span style={{ width: '100px' }}>计划结束:</span>
                  <span>{data.projectInfo.planEndDate}</span>
                </div>
                <div style={{ display: 'flex' }}>
                  <span style={{ width: '100px' }}></span>
                </div>
              </div>
            </Card>
          </Col>

          <Col span={16}>
            <Card
              title="项目进度甘特图"
              bordered={false}
              style={{...cardStyle,height:'100%'}}
              headStyle={headerStyle}
            >
              <ReactEcharts option={ganttChartOption} style={{ height: '220px' }} />
            </Card>
          </Col>
        </Row>

        <Row gutter={[16, 16]} style={{ marginTop: '16px' }}>
          <Col span={8}>
            <Card
              title="人员出勤率"
              bordered={false}
              style={cardStyle}
              headStyle={headerStyle}
            >
              <ReactEcharts option={personnelAttendanceOption} style={{ height: '220px' }} />
            </Card>
          </Col>

          <Col span={8}>
            <Card
              title="参训内容"
              bordered={false}
              style={cardStyle}
              headStyle={headerStyle}
            >
              <ReactEcharts option={trainingContentsOption} style={{ height: '220px' }} />
            </Card>
          </Col>

          <Col span={8}>
            <Card
              title="参训时长"
              bordered={false}
              style={cardStyle}
              headStyle={headerStyle}
            >
              <ReactEcharts option={trainingHoursOption} style={{ height: '220px' }} />
            </Card>
          </Col>
        </Row>

        <Row gutter={[16, 16]} style={{ marginTop: '16px' }}>
          <Col span={24}>
            <Card
              title="任务完成情况"
              bordered={false}
              style={{ height: '300px', backgroundColor: '#0c2135', color: 'white' }}
              headStyle={{ color: 'white', borderBottom: '1px solid #1890ff' }}
            >
              <ReactEcharts option={materialsOption} style={{ height: '220px' }} />
            </Card>
          </Col>
        </Row>
      </div>
    </div>
  );
};

export default Dashboard;